@@ -5,4 +5,4 @@ from phonenumber_field.formfields import PhoneNumberField
 class ContactForm(forms.Form):
     name = forms.CharField(max_length=64, label='Nome Completo')
     email = forms.EmailField()
-    phone = PhoneNumberField(label='Celular')
+    phone = PhoneNumberField(label='Celular', widget=forms.TextInput(attrs={'placeholder': '(11) 98765-1854'}))
